@@ -3,7 +3,7 @@ package Sah::Schema::git::refname;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-27'; # DATE
 our $DIST = 'Sah-Schemas-Git'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Regexp::Pattern::Git;
 
@@ -13,8 +13,10 @@ our $schema = [
         match => $Regexp::Pattern::Git::RE{ref}{pat},
 
         examples => [
+            {value=>'foo', valid=>0, summary=>'No slash'},
             {value=>'foo/bar', valid=>1},
-            {value=>'.foo/bar', valid=>0, summary=>'A slash-separated component begins with dot (rule 1)'},
+            {value=>'.foo', valid=>0, summary=>'Starts with a dot'},
+            {value=>'foo/.bar', valid=>0, summary=>'Starts with a dot'},
         ],
     },
     {},
@@ -36,7 +38,7 @@ Sah::Schema::git::refname - git reference name
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::git::refname (from Perl distribution Sah-Schemas-Git), released on 2020-03-27.
+This document describes version 0.003 of Sah::Schema::git::refname (from Perl distribution Sah-Schemas-Git), released on 2020-03-27.
 
 =head1 SYNOPSIS
 
@@ -72,9 +74,13 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
 Sample data:
 
+ "foo"  # INVALID (No slash)
+
  "foo/bar"  # valid
 
- ".foo/bar"  # INVALID (A slash-separated component begins with dot (rule 1))
+ ".foo"  # INVALID (Starts with a dot)
+
+ "foo/.bar"  # INVALID (Starts with a dot)
 
 =head1 HOMEPAGE
 
